library digital_ocean_rhinosoft;

import 'dart:typed_data';
import 'package:http/http.dart' as http;
import 'package:image_picker/image_picker.dart';
import 'dart:convert';

class DigitalOcean {
  Future uploadFiles(
    String url,
    String bucketName,
    String permission,
    String key,
    String secret,
    String path,
    List<String> filesNames,
    List<Uint8List> data,
  ) async {
    final Map<String, String> headers = {
      'auth': "$key:$secret",
      'Access-Control-Allow-Origin': '*',
    };
    var request = http.MultipartRequest('POST', Uri.parse(url));
    request.headers.addAll(headers);

    for (int i = 0; i < filesNames.length; i++) {
      List<int> list = data[i].cast();
      request.files.add(
          http.MultipartFile.fromBytes('file', list, filename: filesNames[i]));
    }
    // permission public-read
    // permission private
    request.fields.addAll(
        {'bucketName': bucketName, 'path': path, 'permission': permission});
    http.StreamedResponse response = await request.send();
    String converted = await response.stream.bytesToString();
    List<String> links = List.from(json.decode(converted));
    return links;
  }

  Future uploadFile(
      String url,
      String bucketName,
      String permission,
      String key,
      String secret,
      String path,
      String fileName,
      Uint8List data) async {
    final Map<String, String> headers = {
      'auth': "$key:$secret",
      'Access-Control-Allow-Origin': '*',
    };
    http.MultipartRequest request =
        http.MultipartRequest('POST', Uri.parse(url));
    request.headers.addAll(headers);
    List<int> list = data.cast();
    request.files
        .add(http.MultipartFile.fromBytes('file', list, filename: fileName));
    request.fields.addAll(
        {'bucketName': bucketName, 'path': path, 'permission': permission});
    http.StreamedResponse response = await request.send();
    String converted = await response.stream.bytesToString();
    List<String> links = List.from(json.decode(converted));

    return links[0];
  }

  Future uploadImage(
      String url,
      String bucketName,
      String permission,
      String key,
      String secret,
      String path,
      String imageName,
      String imageType,
      XFile image) async {
    final Map<String, String> headers = {
      'auth': "$key:$secret",
      'Access-Control-Allow-Origin': '*',
    };
    http.MultipartRequest request =
        http.MultipartRequest('POST', Uri.parse(url));
    request.headers.addAll(headers);
    Uint8List data = await image.readAsBytes();
    List<int> list = data.cast();
    request.files.add(http.MultipartFile.fromBytes('file', list,
        filename: '$imageName.$imageType'));
    request.fields.addAll(
        {'bucketName': bucketName, 'path': path, 'permission': permission});
    http.StreamedResponse response = await request.send();
    String converted = await response.stream.bytesToString();
    List<String> links = List.from(json.decode(converted));
    return links[0];
  }
}
